@@ -26,31 +26,34 @@ import (
 	"miniflux.app/v2/internal/urllib"
 
 	"github.com/PuerkitoBio/goquery"
+	"github.com/tdewolff/minify/v2"
+	"github.com/tdewolff/minify/v2/svg"
 	"golang.org/x/image/draw"
+	"golang.org/x/image/webp"
 )
 
-type IconFinder struct {
+type iconFinder struct {
 	requestBuilder *fetcher.RequestBuilder
 	websiteURL     string
 	feedIconURL    string
 }
 
-func NewIconFinder(requestBuilder *fetcher.RequestBuilder, websiteURL, feedIconURL string) *IconFinder {
-	return &IconFinder{
+func newIconFinder(requestBuilder *fetcher.RequestBuilder, websiteURL, feedIconURL string) *iconFinder {
+	return &iconFinder{
 		requestBuilder: requestBuilder,
 		websiteURL:     websiteURL,
 		feedIconURL:    feedIconURL,
 	}
 }
 
-func (f *IconFinder) FindIcon() (*model.Icon, error) {
+func (f *iconFinder) findIcon() (*model.Icon, error) {
 	slog.Debug("Begin icon discovery process",
 		slog.String("website_url", f.websiteURL),
 		slog.String("feed_icon_url", f.feedIconURL),
 	)
 
 	if f.feedIconURL != "" {
-		if icon, err := f.FetchFeedIcon(); err != nil {
+		if icon, err := f.fetchFeedIcon(); err != nil {
 			slog.Debug("Unable to download icon from feed",
 				slog.String("website_url", f.websiteURL),
 				slog.String("feed_icon_url", f.feedIconURL),
@@ -61,7 +64,7 @@ func (f *IconFinder) FindIcon() (*model.Icon, error) {
 		}
 	}
 
-	if icon, err := f.FetchIconsFromHTMLDocument(); err != nil {
+	if icon, err := f.fetchIconsFromHTMLDocument(); err != nil {
 		slog.Debug("Unable to fetch icons from HTML document",
 			slog.String("website_url", f.websiteURL),
 			slog.Any("error", err),
@@ -70,10 +73,10 @@ func (f *IconFinder) FindIcon() (*model.Icon, error) {
 		return icon, nil
 	}
 
-	return f.FetchDefaultIcon()
+	return f.fetchDefaultIcon()
 }
 
-func (f *IconFinder) FetchDefaultIcon() (*model.Icon, error) {
+func (f *iconFinder) fetchDefaultIcon() (*model.Icon, error) {
 	slog.Debug("Fetching default icon",
 		slog.String("website_url", f.websiteURL),
 	)
@@ -83,7 +86,7 @@ func (f *IconFinder) FetchDefaultIcon() (*model.Icon, error) {
 		return nil, fmt.Errorf(`icon: unable to join root URL and path: %w`, err)
 	}
 
-	icon, err := f.DownloadIcon(iconURL)
+	icon, err := f.downloadIcon(iconURL)
 	if err != nil {
 		return nil, err
 	}
@@ -91,7 +94,7 @@ func (f *IconFinder) FetchDefaultIcon() (*model.Icon, error) {
 	return icon, nil
 }
 
-func (f *IconFinder) FetchFeedIcon() (*model.Icon, error) {
+func (f *iconFinder) fetchFeedIcon() (*model.Icon, error) {
 	slog.Debug("Fetching feed icon",
 		slog.String("website_url", f.websiteURL),
 		slog.String("feed_icon_url", f.feedIconURL),
@@ -102,10 +105,10 @@ func (f *IconFinder) FetchFeedIcon() (*model.Icon, error) {
 		return nil, fmt.Errorf(`icon: unable to convert icon URL to absolute URL: %w`, err)
 	}
 
-	return f.DownloadIcon(iconURL)
+	return f.downloadIcon(iconURL)
 }
 
-func (f *IconFinder) FetchIconsFromHTMLDocument() (*model.Icon, error) {
+func (f *iconFinder) fetchIconsFromHTMLDocument() (*model.Icon, error) {
 	slog.Debug("Searching icons from HTML document",
 		slog.String("website_url", f.websiteURL),
 	)
@@ -145,14 +148,14 @@ func (f *IconFinder) FetchIconsFromHTMLDocument() (*model.Icon, error) {
 			return nil, fmt.Errorf(`icon: unable to convert icon URL to absolute URL: %w`, err)
 		}
 
-		if icon, err := f.DownloadIcon(iconURL); err != nil {
+		if icon, err := f.downloadIcon(iconURL); err != nil {
 			slog.Debug("Unable to download icon from HTML document",
 				slog.String("website_url", f.websiteURL),
 				slog.String("icon_url", iconURL),
 				slog.Any("error", err),
 			)
 		} else if icon != nil {
-			slog.Debug("Found icon from HTML document",
+			slog.Debug("Downloaded icon from HTML document",
 				slog.String("website_url", f.websiteURL),
 				slog.String("icon_url", iconURL),
 			)
@@ -163,7 +166,7 @@ func (f *IconFinder) FetchIconsFromHTMLDocument() (*model.Icon, error) {
 	return nil, nil
 }
 
-func (f *IconFinder) DownloadIcon(iconURL string) (*model.Icon, error) {
+func (f *iconFinder) downloadIcon(iconURL string) (*model.Icon, error) {
 	slog.Debug("Downloading icon",
 		slog.String("website_url", f.websiteURL),
 		slog.String("icon_url", iconURL),
@@ -193,21 +196,33 @@ func (f *IconFinder) DownloadIcon(iconURL string) (*model.Icon, error) {
 }
 
 func resizeIcon(icon *model.Icon) *model.Icon {
-	r := bytes.NewReader(icon.Content)
-
-	if !slices.Contains([]string{"image/jpeg", "image/png", "image/gif"}, icon.MimeType) {
-		slog.Info("icon isn't a png/gif/jpeg/ico, can't resize", slog.String("mimetype", icon.MimeType))
+	if icon.MimeType == "image/svg+xml" {
+		minifier := minify.New()
+		minifier.AddFunc("image/svg+xml", svg.Minify)
+		var err error
+		// minifier.Bytes returns the data unchanged in case of error.
+		icon.Content, err = minifier.Bytes("image/svg+xml", icon.Content)
+		if err != nil {
+			slog.Error("Unable to minify SVG icon", slog.Any("error", err))
+		}
 		return icon
 	}
 
+	if !slices.Contains([]string{"image/jpeg", "image/png", "image/gif", "image/webp"}, icon.MimeType) {
+		slog.Info("Icon resize skipped: unsupported MIME type", slog.String("mime_type", icon.MimeType))
+		return icon
+	}
+
+	r := bytes.NewReader(icon.Content)
+
 	// Don't resize icons that we can't decode, or that already have the right size.
 	config, _, err := image.DecodeConfig(r)
 	if err != nil {
-		slog.Warn("unable to decode the metadata of the icon", slog.Any("error", err))
+		slog.Warn("Unable to decode icon metadata", slog.Any("error", err))
 		return icon
 	}
 	if config.Height <= 32 && config.Width <= 32 {
-		slog.Debug("icon don't need to be rescaled", slog.Int("height", config.Height), slog.Int("width", config.Width))
+		slog.Debug("Icon doesn't need to be resized", slog.Int("height", config.Height), slog.Int("width", config.Width))
 		return icon
 	}
 
@@ -221,9 +236,11 @@ func resizeIcon(icon *model.Icon) *model.Icon {
 		src, err = png.Decode(r)
 	case "image/gif":
 		src, err = gif.Decode(r)
+	case "image/webp":
+		src, err = webp.Decode(r)
 	}
 	if err != nil || src == nil {
-		slog.Warn("unable to decode the icon", slog.Any("error", err))
+		slog.Warn("Unable to decode icon image", slog.Any("error", err))
 		return icon
 	}
 
@@ -232,7 +249,8 @@ func resizeIcon(icon *model.Icon) *model.Icon {
 
 	var b bytes.Buffer
 	if err = png.Encode(io.Writer(&b), dst); err != nil {
-		slog.Warn("unable to encode the new icon", slog.Any("error", err))
+		slog.Warn("Unable to encode resized icon", slog.Any("error", err))
+		return icon
 	}
 
 	icon.Content = b.Bytes()
@@ -241,13 +259,6 @@ func resizeIcon(icon *model.Icon) *model.Icon {
 }
 
 func findIconURLsFromHTMLDocument(body io.Reader, contentType string) ([]string, error) {
-	queries := []string{
-		"link[rel='icon' i]",
-		"link[rel='shortcut icon' i]",
-		"link[rel='icon shortcut' i]",
-		"link[rel='apple-touch-icon-precomposed.png']",
-	}
-
 	htmlDocumentReader, err := encoding.NewCharsetReader(body, contentType)
 	if err != nil {
 		return nil, fmt.Errorf("icon: unable to create charset reader: %w", err)
@@ -258,20 +269,26 @@ func findIconURLsFromHTMLDocument(body io.Reader, contentType string) ([]string,
 		return nil, fmt.Errorf("icon: unable to read document: %v", err)
 	}
 
+	queries := [...]string{
+		"link[rel='icon' i][href]",
+		"link[rel='shortcut icon' i][href]",
+		"link[rel='icon shortcut' i][href]",
+		"link[rel='apple-touch-icon'][href]",
+	}
+
 	var iconURLs []string
 	for _, query := range queries {
 		slog.Debug("Searching icon URL in HTML document", slog.String("query", query))
 
-		doc.Find(query).Each(func(i int, s *goquery.Selection) {
-			if href, exists := s.Attr("href"); exists {
-				if iconURL := strings.TrimSpace(href); iconURL != "" {
-					iconURLs = append(iconURLs, iconURL)
-					slog.Debug("Found icon URL in HTML document",
-						slog.String("query", query),
-						slog.String("icon_url", iconURL))
-				}
+		for _, s := range doc.Find(query).EachIter() {
+			href, _ := s.Attr("href")
+			if iconURL := strings.TrimSpace(href); iconURL != "" {
+				iconURLs = append(iconURLs, iconURL)
+				slog.Debug("Found icon URL in HTML document",
+					slog.String("query", query),
+					slog.String("icon_url", iconURL))
 			}
-		})
+		}
 	}
 
 	return iconURLs, nil
