@@ -9,6 +9,7 @@ import (
 	"fmt"
 	"io"
 	"strings"
+	"unicode/utf8"
 
 	"miniflux.app/v2/internal/reader/encoding"
 )
@@ -16,11 +17,15 @@ import (
 // NewXMLDecoder returns a XML decoder that filters illegal characters.
 func NewXMLDecoder(data io.ReadSeeker) *xml.Decoder {
 	var decoder *xml.Decoder
-	buffer, _ := io.ReadAll(data)
-	enc := getEncoding(buffer)
+
+	// This is way fasted than io.ReadAll(data) as the buffer can be allocated in one go instead of dynamically grown.
+	buffer := &bytes.Buffer{}
+	io.Copy(buffer, data)
+
+	enc := getEncoding(buffer.Bytes())
 	if enc == "" || strings.EqualFold(enc, "utf-8") {
 		// filter invalid chars now, since decoder.CharsetReader not called for utf-8 content
-		filteredBytes := bytes.Map(filterValidXMLChar, buffer)
+		filteredBytes := filterValidXMLChars(buffer.Bytes())
 		decoder = xml.NewDecoder(bytes.NewReader(filteredBytes))
 	} else {
 		// filter invalid chars later within decoder.CharsetReader
@@ -39,13 +44,34 @@ func NewXMLDecoder(data io.ReadSeeker) *xml.Decoder {
 		if err != nil {
 			return nil, fmt.Errorf("encoding: unable to read data: %w", err)
 		}
-		filteredBytes := bytes.Map(filterValidXMLChar, rawData)
+		filteredBytes := filterValidXMLChars(rawData)
 		return bytes.NewReader(filteredBytes), nil
 	}
 
 	return decoder
 }
 
+// filterValidXMLChars filters inplace invalid XML characters.
+// This function is inspired from bytes.Map
+func filterValidXMLChars(s []byte) []byte {
+	j := 0
+	for i := 0; i < len(s); {
+		wid := 1
+		r := rune(s[i])
+		if r >= utf8.RuneSelf {
+			r, wid = utf8.DecodeRune(s[i:])
+		}
+		if r != utf8.RuneError {
+			if r = filterValidXMLChar(r); r >= 0 {
+				utf8.EncodeRune(s[j:], r)
+				j += wid
+			}
+		}
+		i += wid
+	}
+	return s[:j]
+}
+
 // This function is copied from encoding/xml package,
 // and is used to check if all the characters are legal.
 func filterValidXMLChar(r rune) rune {
@@ -62,7 +88,7 @@ func filterValidXMLChar(r rune) rune {
 
 // This function is copied from encoding/xml's procInst and adapted for []bytes instead of string
 func getEncoding(b []byte) string {
-	// TODO: this parsing is somewhat lame and not exact.
+	// This parsing is somewhat lame and not exact.
 	// It works for all actual cases, though.
 	idx := bytes.Index(b, []byte("encoding="))
 	if idx == -1 {
