@@ -6,21 +6,28 @@ package static // import "miniflux.app/v2/internal/ui/static"
 import (
 	"bytes"
 	"embed"
-	"fmt"
+	"log/slog"
+	"slices"
+	"strings"
 
 	"miniflux.app/v2/internal/crypto"
 
 	"github.com/tdewolff/minify/v2"
 	"github.com/tdewolff/minify/v2/css"
 	"github.com/tdewolff/minify/v2/js"
+	"github.com/tdewolff/minify/v2/svg"
 )
 
+type asset struct {
+	Data     []byte
+	Checksum string
+}
+
 // Static assets.
 var (
-	StylesheetBundleChecksums map[string]string
-	StylesheetBundles         map[string][]byte
-	JavascriptBundleChecksums map[string]string
-	JavascriptBundles         map[string][]byte
+	StylesheetBundles map[string]asset
+	JavascriptBundles map[string]asset
+	BinaryBundles     map[string]asset
 )
 
 //go:embed bin/*
@@ -32,42 +39,42 @@ var stylesheetFiles embed.FS
 //go:embed js/*.js
 var javascriptFiles embed.FS
 
-var binaryFileChecksums map[string]string
-
-// CalculateBinaryFileChecksums generates hash of embed binary files.
-func CalculateBinaryFileChecksums() error {
-	binaryFileChecksums = make(map[string]string)
-
+func GenerateBinaryBundles() error {
 	dirEntries, err := binaryFiles.ReadDir("bin")
 	if err != nil {
 		return err
 	}
+	BinaryBundles = make(map[string]asset, len(dirEntries))
+
+	minifier := minify.New()
+	minifier.Add("image/svg+xml", &svg.Minifier{
+		KeepComments: true, // needed to keep the license
+	})
 
 	for _, dirEntry := range dirEntries {
-		data, err := LoadBinaryFile(dirEntry.Name())
+		name := dirEntry.Name()
+		data, err := binaryFiles.ReadFile("bin/" + name)
 		if err != nil {
 			return err
 		}
 
-		binaryFileChecksums[dirEntry.Name()] = crypto.HashFromBytes(data)
+		if strings.HasSuffix(name, ".svg") {
+			// minifier.Bytes returns the data unchanged in case of error.
+			data, err = minifier.Bytes("image/svg+xml", data)
+			if err != nil {
+				slog.Error("Unable to minimize the svg file", slog.String("filename", name), slog.Any("error", err))
+			}
+		}
+
+		BinaryBundles[name] = asset{
+			Data:     data,
+			Checksum: crypto.HashFromBytes(data),
+		}
 	}
 
 	return nil
 }
 
-// LoadBinaryFile loads an embed binary file.
-func LoadBinaryFile(filename string) ([]byte, error) {
-	return binaryFiles.ReadFile(fmt.Sprintf(`bin/%s`, filename))
-}
-
-// GetBinaryFileChecksum returns a binary file checksum.
-func GetBinaryFileChecksum(filename string) (string, error) {
-	if _, found := binaryFileChecksums[filename]; !found {
-		return "", fmt.Errorf(`static: unable to find checksum for %q`, filename)
-	}
-	return binaryFileChecksums[filename], nil
-}
-
 // GenerateStylesheetsBundles creates CSS bundles.
 func GenerateStylesheetsBundles() error {
 	var bundles = map[string][]string{
@@ -79,8 +86,7 @@ func GenerateStylesheetsBundles() error {
 		"system_sans_serif": {"css/system.css", "css/sans_serif.css", "css/common.css"},
 	}
 
-	StylesheetBundles = make(map[string][]byte)
-	StylesheetBundleChecksums = make(map[string]string)
+	StylesheetBundles = make(map[string]asset, len(bundles))
 
 	minifier := minify.New()
 	minifier.AddFunc("text/css", css.Minify)
@@ -102,42 +108,35 @@ func GenerateStylesheetsBundles() error {
 			return err
 		}
 
-		StylesheetBundles[bundle] = minifiedData
-		StylesheetBundleChecksums[bundle] = crypto.HashFromBytes(minifiedData)
+		StylesheetBundles[bundle] = asset{
+			Data:     minifiedData,
+			Checksum: crypto.HashFromBytes(minifiedData),
+		}
 	}
 
 	return nil
 }
 
 // GenerateJavascriptBundles creates JS bundles.
-func GenerateJavascriptBundles() error {
+func GenerateJavascriptBundles(webauthnEnabled bool) error {
 	var bundles = map[string][]string{
 		"app": {
 			"js/tt.js", // has to be first
-			"js/dom_helper.js",
 			"js/touch_handler.js",
 			"js/keyboard_handler.js",
-			"js/request_builder.js",
 			"js/modal_handler.js",
 			"js/app.js",
-			"js/webauthn_handler.js",
-			"js/bootstrap.js",
 		},
 		"service-worker": {
 			"js/service_worker.js",
 		},
 	}
 
-	var prefixes = map[string]string{
-		"app": "(function(){'use strict';",
+	if webauthnEnabled {
+		bundles["app"] = slices.Insert(bundles["app"], 1, "js/webauthn_handler.js")
 	}
 
-	var suffixes = map[string]string{
-		"app": "})();",
-	}
-
-	JavascriptBundles = make(map[string][]byte)
-	JavascriptBundleChecksums = make(map[string]string)
+	JavascriptBundles = make(map[string]asset, len(bundles))
 
 	jsMinifier := js.Minifier{Version: 2020}
 
@@ -147,10 +146,6 @@ func GenerateJavascriptBundles() error {
 	for bundle, srcFiles := range bundles {
 		var buffer bytes.Buffer
 
-		if prefix, found := prefixes[bundle]; found {
-			buffer.WriteString(prefix)
-		}
-
 		for _, srcFile := range srcFiles {
 			fileData, err := javascriptFiles.ReadFile(srcFile)
 			if err != nil {
@@ -160,17 +155,15 @@ func GenerateJavascriptBundles() error {
 			buffer.Write(fileData)
 		}
 
-		if suffix, found := suffixes[bundle]; found {
-			buffer.WriteString(suffix)
-		}
-
 		minifiedData, err := minifier.Bytes("text/javascript", buffer.Bytes())
 		if err != nil {
 			return err
 		}
 
-		JavascriptBundles[bundle] = minifiedData
-		JavascriptBundleChecksums[bundle] = crypto.HashFromBytes(minifiedData)
+		JavascriptBundles[bundle] = asset{
+			Data:     minifiedData,
+			Checksum: crypto.HashFromBytes(minifiedData),
+		}
 	}
 
 	return nil
